=====================
Django Suit Dashboard
=====================

.. start-badges


|travis|
|codacygrade|
|codacycoverage|
|version|
|wheel|
|pyup|
|gitter|


.. |travis| image:: https://travis-ci.org/Pawamoy/django-suit-dashboard.svg?branch=master
    :target: https://travis-ci.org/Pawamoy/django-suit-dashboard/
    :alt: Travis-CI Build Status

.. |codacygrade| image:: https://api.codacy.com/project/badge/Grade/f17fe5fdb2a248efa3e9eccd4b7045a7
    :target: https://www.codacy.com/app/Pawamoy/django-suit-dashboard/dashboard
    :alt: Codacy Code Quality Status

.. |codacycoverage| image:: https://api.codacy.com/project/badge/Coverage/f17fe5fdb2a248efa3e9eccd4b7045a7
    :target: https://www.codacy.com/app/Pawamoy/django-suit-dashboard/dashboard
    :alt: Codacy Code Coverage

.. |pyup| image:: https://pyup.io/repos/github/Pawamoy/django-suit-dashboard/shield.svg
    :target: https://pyup.io/repos/github/Pawamoy/django-suit-dashboard/
    :alt: Updates

.. |version| image:: https://img.shields.io/pypi/v/django-suit-dashboard.svg?style=flat
    :target: https://pypi.python.org/pypi/django-suit-dashboard/
    :alt: PyPI Package latest release

.. |wheel| image:: https://img.shields.io/pypi/wheel/django-suit-dashboard.svg?style=flat
    :target: https://pypi.python.org/pypi/django-suit-dashboard/
    :alt: PyPI Wheel

.. |gitter| image:: https://badges.gitter.im/Pawamoy/django-suit-dashboard.svg
    :target: https://gitter.im/Pawamoy/django-suit-dashboard
    :alt: Join the chat at https://gitter.im/Pawamoy/django-suit-dashboard


.. end-badges

Create a dashboard within Django admin interface.

Screenshot
==========

.. image:: https://cloud.githubusercontent.com/assets/3999221/14685134/8cde04be-0733-11e6-8eda-b59f2e2fa6c3.png
    :alt: Screenshot

License
=======

Software licensed under `ISC`_ license.

.. _ISC: https://www.isc.org/downloads/software-support-policy/isc-license/

Installation
============

::

    pip install django-suit-dashboard

Documentation
=============

`On ReadTheDocs`_

.. _`On ReadTheDocs`: http://django-suit-dashboard.readthedocs.io/

Development
===========

To run all the tests: ``tox``
